library(tidyr)
library(stringr)
library(ggplot2)

df1 <- read.delim('Mattiello&Dressler Survey Results_1.csv')
df1 <- df1[complete.cases(df1),]

df2 <- read.delim('Mattiello&Dressler Survey Results_2.csv')
df2 <- df1[complete.cases(df2),]

rem <- 'Please.rate.the.following.definitions.as..1.if.they.are.true..2.if.they.are.more.true.than.false..3.if.they.are.more.false.than.true..and.4.if.they.are.false..'
colnames(df1) <- str_replace(colnames(df1), rem, '')
colnames(df2) <- str_replace(colnames(df2), rem, '')

df1 <- data.frame(lapply(df1, function(x) {
                    gsub(" True", "", x)
                }))
df1 <- data.frame(lapply(df1, function(x) {
  gsub(" False", "", x)
}))

df1 <- data.frame(lapply(df1, function(x) {
  gsub("1, 2", "1.5", x)
}))

df1 <- data.frame(lapply(df1, function(x) {
  gsub("2, 3", "2.5", x)
}))

df1 <- data.frame(lapply(df1, function(x) {
  gsub("3, 4", "3.5", x)
}))


df2 <- data.frame(lapply(df2, function(x) {
  gsub(" True", "", x)
}))
df2 <- data.frame(lapply(df2, function(x) {
  gsub(" False", "", x)
}))

df2 <- data.frame(lapply(df2, function(x) {
  gsub("1, 2", "1.5", x)
}))

df2 <- data.frame(lapply(df2, function(x) {
  gsub("2, 3", "2.5", x)
}))

df2 <- data.frame(lapply(df2, function(x) {
  gsub("3, 4", "3.5", x)
}))


df1$id.var <- seq(1, dim(df1)[1])
df2$id.var <- seq(1 + dim(df1)[1], dim(df2)[1] + dim(df1)[1])

df1.data <- df1[c(6:dim(df1)[2])]
df2.data <- df2[c(6:dim(df2)[2])]

pivot.cols.1 <- c(1:dim(df1.data)[2]-1)
df1.long <- pivot_longer(df1.data,
                         cols = all_of(pivot.cols.1))
pivot.cols.2 <- c(1:dim(df2.data)[2]-1)
df2.long <- pivot_longer(df2.data,
                         cols = all_of(pivot.cols.2))
df <- rbind(df1.long, df2.long)
df <- data.frame(df)

df$type <- '-'
df$type[grepl('.that.', df$name)] <- 'N who/that X-s'
df$type[grepl('.who.', df$name)] <- 'N who/that X-s'
df$type[grepl('.which.', df$name)] <- 'N who/that X-s'
df$type[grepl('er.of.', df$name)] <- 'X-er of'
df$type[grepl('or.of.', df$name)] <- 'X-er of'

exclude <- c('\\.PLAYER\\.',
             '\\.CUTTER\\.',
             '\\.MAKER\\.',
             '\\.HOLDER\\.',
             '\\.KILLER\\.',
             '\\.BREAKER\\.',
             '\\.HAMMER\\.')

for ( excl in exclude )
{
  df <- df[!grepl(excl, df$name),]
}

df$name <- sub('.', '', df$name)
df$name <- sapply(str_extract_all(df$name, '\\b[A-Z]+\\b'), paste, collapse='-')
colnames(df) <- c('id.var', 'compound', 'value', 'type')
df$value <- as.numeric(df$value)

df3 <- read.delim('CompiledMattiello&DresslerData_2019_07_22.csv')
df3 <- df3[df3$Did.the.participants.see.the..er..version. %in% c('YES', 'NO'),]
df3 <- df3[c(2, 20, 6, 15)]
colnames(df3) <- c('id.var', 'compound', 'value', 'type')
df3$type[df3$type == 'YES'] <- 'X-er of'
df3$type[df3$type == 'NO'] <- 'N who/that X-s'
df3$id.var <- df3$id.var + max(df$id.var)

df.all <- rbind(df, df3)
df.all$compound <- as.factor(df.all$compound)
df.all$type <- as.factor(df.all$type)

mean.df <-  aggregate(df.all[c(2:4)],
            by=list(df.all$compound, df.all$type),
            mean)

mean.df <- mean.df[c(1,2,4)]
colnames(mean.df) <- c('compound', 'type', 'value')

ggplot(mean.df, aes(x=compound, y=value, fill=type)) + 
  geom_bar(stat="identity", position = "dodge") + 
  scale_fill_brewer(palette = "Set1") +
  theme(axis.text.x = element_text(angle = 45, vjust = 0.5, hjust=1)) +
  xlab(label='') +
  theme(plot.margin = unit(c(1,1,1,1), "cm"))


for (c in levels(df.all$compound) )
{
   v1 <- df.all[df.all$compound == c & df.all$type == 'N who/that X-s',]
   v2 <- df.all[df.all$compound == c & df.all$type == 'X-er of',]
   print(t.test(v1$value, v2$value)$p.value)
}

comp.df <- cbind(mean.df[c(1:24),], mean.df[c(25:48),])
comp.df$diff <- comp.df[,3]-comp.df[,6]
comp.df$ratio <- log(comp.df[,3]/comp.df[,6])
barplot(comp.df$diff, names.arg = comp.df$compound, las=2)

class.df <- read.delim('classifications_2.csv')

P <- ggplot(class.df) + 
  geom_bar(aes(x=Synthetic.Compound., y=Questionnaire.difference), stat='identity') +
  #geom_point(aes(x = Synthetic.Compound.,y=Questionnaire.diiference, color=Questionnaire.diiference)) +
  scale_color_brewer(palette = 'Purples')

  scale_fill_gradient(low='blue', high='red')

  scale_color_gradient2(midpoint=mid, low="blue", mid="white",
                        high="red", space ="Lab" )
